autowisp.database.data_model.light_curve_status module — AutoWISP documentation

# autowisp.database.data_model.light_curve_status module

## Class Inheritance Diagram

Define table tracking the state of interrupted lightcurve processing.

class autowisp.database.data_model.light_curve_status.LightCurveStatus(**kwargs)

  Bases: `DataModelBase`

  Table tracking the status of lightcurves for interrupted steps.

  id

    A unique identifier for each row.

  processing
  progress_id

    The ID of the LC processing progress which was interrupted

  status

    The status of the processing (0 = started, >0 = successfully saved progress, negative values indicate various reasons for failure).

  timestamp

    When record was last changed